@@ -30,14 +30,14 @@
 #include <tqlabel.h>
 #include <tqregexp.h>
 
-#include <kaction.h>
+#include <tdeaction.h>
 #include <klineedit.h>
 #include <kmdcodec.h>       //md5sum
-#include <kmessagebox.h>
-#include <kio/job.h>
-#include <kio/jobclasses.h>
-#include <kprotocolmanager.h>
-#include <kshortcut.h>
+#include <tdemessagebox.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
+#include <tdeprotocolmanager.h>
+#include <tdeshortcut.h>
 #include <kurl.h>
 
 #include <time.h>
@@ -48,7 +48,7 @@ using namespace LastFm;
 ///////////////////////////////////////////////////////////////////////////////
 // CLASS AmarokHttp
 // AmarokHttp is a hack written so that lastfm code could easily use something proxy aware.
-// DO NOT use this class for anything else, use KIO directly instead.
+// DO NOT use this class for anything else, use TDEIO directly instead.
 ////////////////////////////////////////////////////////////////////////////////
 AmarokHttp::AmarokHttp ( const TQString& hostname, TQ_UINT16 port,
                          TQObject* parent )
@@ -68,11 +68,11 @@ AmarokHttp::get ( const TQString & path )
     m_done = false;
     m_error = TQHttp::NoError;
     m_state = TQHttp::Connecting;
-    KIO::TransferJob *job = KIO::get(uri, true, false);
-    connect(job,  TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(slotData(KIO::Job*, const TQByteArray&)));
-    connect(job,  TQT_SIGNAL(result(KIO::Job*)),
-            this, TQT_SLOT(slotResult(KIO::Job*)));
+    TDEIO::TransferJob *job = TDEIO::get(uri, true, false);
+    connect(job,  TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+    connect(job,  TQT_SIGNAL(result(TDEIO::Job*)),
+            this, TQT_SLOT(slotResult(TDEIO::Job*)));
 
     return 0;
 }
@@ -96,7 +96,7 @@ AmarokHttp::error()
 }
 
 void
-AmarokHttp::slotData(KIO::Job*, const TQByteArray& data)
+AmarokHttp::slotData(TDEIO::Job*, const TQByteArray& data)
 {
     if( data.size() == 0 ) {
         return;
@@ -110,7 +110,7 @@ AmarokHttp::slotData(KIO::Job*, const TQByteArray& data)
 }
 
 void
-AmarokHttp::slotResult(KIO::Job* job)
+AmarokHttp::slotResult(TDEIO::Job* job)
 {
     bool err = job->error();
     if( err || m_error != TQHttp::NoError ) {
@@ -136,14 +136,14 @@ Controller::Controller()
     : TQObject( EngineController::instance(), "lastfmController" )
     , m_service( 0 )
 {
-    KActionCollection* ac = Amarok::actionCollection();
-    m_actionList.append( new KAction( i18n( "Ban" ), Amarok::icon( "remove" ),
+    TDEActionCollection* ac = Amarok::actionCollection();
+    m_actionList.append( new TDEAction( i18n( "Ban" ), Amarok::icon( "remove" ),
                          KKey( TQt::CTRL | TQt::Key_B ), this, TQT_SLOT( ban() ), ac, "ban" ) );
 
-    m_actionList.append( new KAction( i18n( "Love" ), Amarok::icon( "love" ),
+    m_actionList.append( new TDEAction( i18n( "Love" ), Amarok::icon( "love" ),
                          KKey( TQt::CTRL | TQt::Key_L ), this, TQT_SLOT( love() ), ac, "love" ) );
 
-    m_actionList.append( new KAction( i18n( "Skip" ), Amarok::icon( "next" ),
+    m_actionList.append( new TDEAction( i18n( "Skip" ), Amarok::icon( "next" ),
                          KKey( TQt::CTRL | TQt::Key_K ), this, TQT_SLOT( skip() ), ac, "skip" ) );
     setActionsEnabled( false );
 }
@@ -289,7 +289,7 @@ Controller::setActionsEnabled( bool enable )
     Amarok::actionCollection()->action( "play_pause" )->setEnabled( !enable );
     Amarok::actionCollection()->action( "pause" )->setEnabled( !enable );
 
-    KAction* action;
+    TDEAction* action;
     for( action = m_actionList.first(); action; action = m_actionList.next() )
         action->setEnabled( enable );
 }
@@ -481,7 +481,7 @@ WebService::handshake( const TQString& username, const TQString& password )
         m_proxyUrl = TQString( "http://localhost:%1/lastfm.mp3" ).arg( port );
     
         m_server = new Amarok::ProcIO();
-        m_server->setComm( KProcess::Communication( KProcess::AllOutput ) );
+        m_server->setComm( TDEProcess::Communication( TDEProcess::AllOutput ) );
         *m_server << "amarok_proxy.rb";
         *m_server << "--lastfm";
         *m_server << TQString::number( port );
@@ -506,7 +506,7 @@ WebService::handshake( const TQString& username, const TQString& password )
             return false;
     
         connect( m_server, TQT_SIGNAL( readReady( KProcIO* ) ), this, TQT_SLOT( readProxy() ) );
-        connect( m_server, TQT_SIGNAL( processExited( KProcess* ) ), Controller::instance(), TQT_SLOT( playbackStopped() ) );
+        connect( m_server, TQT_SIGNAL( processExited( TDEProcess* ) ), Controller::instance(), TQT_SLOT( playbackStopped() ) );
     }
     else
         m_proxyUrl = m_streamUrl.toString();
@@ -620,13 +620,13 @@ WebService::metaDataFinished( int /*id*/, bool error ) //SLOT
         return;
     }
 
-    KIO::Job* job = KIO::storedGet( u, true, false );
-    connect( job, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( fetchImageFinished( KIO::Job* ) ) );
+    TDEIO::Job* job = TDEIO::storedGet( u, true, false );
+    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( fetchImageFinished( TDEIO::Job* ) ) );
 }
 
 
 void
-WebService::fetchImageFinished( KIO::Job* job ) //SLOT
+WebService::fetchImageFinished( TDEIO::Job* job ) //SLOT
 {
     DEBUG_BLOCK
 
@@ -634,7 +634,7 @@ WebService::fetchImageFinished( KIO::Job* job ) //SLOT
         const TQString path = Amarok::saveLocation() + "lastfm_image.png";
         const int size = AmarokConfig::coverPreviewSize();
 
-        TQImage img( static_cast<KIO::StoredTransferJob*>( job )->data() );
+        TQImage img( static_cast<TDEIO::StoredTransferJob*>( job )->data() );
         img.smoothScale( size, size ).save( path, "PNG" );
 
         m_metaBundle.lastFmBundle()->setImageUrl( CollectionDB::makeShadowedImage( path, false ) );
